@@ -26,7 +26,17 @@ import javax.swing.filechooser.FileFilter;
 public class FastQFileFilter extends FileFilter {
 
 	public boolean accept(File f) {
-		return true;
+	
+		if (f.isDirectory()) return true;
+		
+		String [] endings = new String [] {"fastq","fq","fastq.gz","fq.gz","fastq.bz","fastq.bz2"};
+
+		for (int i=0;i<endings.length;i++) {
+			if (f.getName().toLowerCase().endsWith(endings[i])) {
+				return true;
+			}
+		}
+		return false;
 	}
 
 	public String getDescription() {
