@@ -1,9 +1,9 @@
 /**
  * Copyright Copyright 2014-17 Simon Andrews
  *
- *    This file is part of SeqMonk.
+ *    This file is part of FastQC.
  *
- *    SeqMonk is free software; you can redistribute it and/or modify
+ *    Conclave is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation; either version 3 of the License, or
  *    (at your option) any later version.
@@ -14,7 +14,7 @@
  *    GNU General Public License for more details.
  *
  *    You should have received a copy of the GNU General Public License
- *    along with SeqMonk; if not, write to the Free Software
+ *    along with Conclave; if not, write to the Free Software
  *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 package uk.ac.babraham.FastQC.Utilities;
@@ -45,6 +45,23 @@ public class ImageToBase64 {
 		}
 		
 	}
+
+	public static String svgImageToBase64 (String svgdata) {
+		
+
+		// We've moved to using the Java.util Base64 encoder which means that
+		// SVG output will only work on java v8+ but there was a bug in the 
+		// library we were using which caused the last character to get lost
+		// some times so this is an easy fix and no one is using java <v8 
+		// any more.
+
+		String data = "data:image/svg+xml;base64,"+java.util.Base64.getEncoder().encodeToString(svgdata.getBytes());			
+
+		return(data);
+		
+	}
+
+	
 	
 	
 }
